@@ -2,14 +2,13 @@ import * as React from 'react';
 import * as classNames from 'classnames';
 import * as _ from 'lodash';
 import { modelFor } from '@console/internal/module/k8s';
-import { TopologyDataObject } from '../topology-types';
-import { getTopologyResourceObject } from '../topology-utils';
+import { OdcNodeModel } from '../topology-types';
 import ApplicationGroupResource from './ApplicationGroupResource';
 
 import './TopologyApplicationResources.scss';
 
 export type TopologyApplicationResourcesProps = {
-  resources: TopologyDataObject[];
+  resources: OdcNodeModel[];
   group: string;
 };
 
@@ -17,8 +16,7 @@ const TopologyApplicationResources: React.FC<TopologyApplicationResourcesProps>
   resources,
   group,
 }) => {
-  const resourcesData = resources.reduce((acc, currVal) => {
-    const resource = getTopologyResourceObject(currVal);
+  const resourcesData = resources.reduce((acc, { resource }) => {
     acc[resource.kind] = [...(acc[resource.kind] ? acc[resource.kind] : []), resource];
     return acc;
   }, {});
