@@ -7,24 +7,19 @@ import { sampleEventSourceSinkbinding } from '../../../topology/__tests__/topolo
 type SinkSourceProps = React.ComponentProps<typeof SinkSource>;
 
 describe('SinkSource', () => {
-  let formProps: SinkSourceProps;
-  let eventSourceForm: ShallowWrapper<SinkSourceProps>;
-  beforeEach(() => {
-    formProps = {
-      source: sampleEventSourceSinkbinding.data[0],
-    };
-    eventSourceForm = shallow(<SinkSource {...formProps} />);
-  });
+  const formProps: SinkSourceProps = {
+    source: sampleEventSourceSinkbinding.data[0],
+  };
+  const eventSourceForm: ShallowWrapper<SinkSourceProps> = shallow(<SinkSource {...formProps} />);
   it('should render Formik with proper initial values', () => {
     const formikForm = eventSourceForm.find(Formik);
     expect(formikForm).toHaveLength(1);
-    expect(formikForm.get(0).props.initialValues.sink.ref.name).toBe('wss-event-display');
+    expect(formikForm.get(0).props.initialValues.sink.name).toBe('wss-event-display');
   });
 
   it('should render Formik child with proper props', () => {
     const formikFormRender = eventSourceForm.find(Formik).get(0).props;
     expect(formikFormRender.children).toHaveLength(1);
-    expect(formikFormRender.children().props.namespace).toBe('testproject3');
     expect(formikFormRender.children().props.resourceName).toBe('bind-wss');
   });
 });
